@@ -68,6 +68,8 @@ protected:
   // ===================================================
 
   // Init terms that is constant for the whole network
+  virtual void initTree();
+
   virtual void initNetwork();
 
   virtual void initSuperNetwork();
@@ -178,6 +180,13 @@ inline unsigned int InfomapOptimizer<Objective>::numActiveModules() const
 // Run: Init: *
 // ===================================================
 
+template <typename Objective>
+inline void InfomapOptimizer<Objective>::initTree()
+{
+  Log(4) << "InfomapOptimizer::initTree()...\n";
+  m_objective.initTree(m_infomap->root());
+}
+
 template <typename Objective>
 inline void InfomapOptimizer<Objective>::initNetwork()
 {
@@ -185,7 +194,7 @@ inline void InfomapOptimizer<Objective>::initNetwork()
   m_objective.initNetwork(m_infomap->root());
 
   if (!m_infomap->isMainInfomap())
-    m_objective.initSubNetwork(m_infomap->root());
+    m_objective.initSubNetwork(m_infomap->root()); //TODO: Already called in initNetwork?
 }
 
 template <typename Objective>
